@@ -17,20 +17,48 @@ import paramiko
 import minio
 import redis
 import uuid
-
-from sqlalchemy import true
+import requests
 
 
 class UniUtil:
     """统一处理工具类"""
 
     @staticmethod
-    def get_uuid(params: dict):
+    def verify_url(url: str):
+        """判断url是否可用"""
+        res = False
+        try:
+            requests.packages.urllib3.disable_warnings()
+            rep = requests.get(url, verify=False)
+            if rep.status_code != 400:
+                res = True
+        except Exception as e:
+            pass
+        return res
+
+    @staticmethod
+    def uuidd(param: dict = None):
+        """字典uuid"""
+        if param is None:
+            return uuid.uuid1()
+        else:
+            p1 = sorted(param.items(), key=lambda x: x[0])
+            p2 = [str(p) for p in p1]
+            p3 = '|'.join(p2)
+            return UniUtil.uuids(p3)
+
+    @staticmethod
+    def uuids(param: str = None):
+        """字典uuid"""
+        if param is None:
+            return uuid.uuid1()
+        else:
+            return str(uuid.uuid3(uuid.NAMESPACE_OID, param))
+
+    @staticmethod
+    def get_uuid(param: dict = None):
         """基于名字的MD5散列值，同一命名空间的同一名字生成相同的uuid"""
-        p1 = sorted(params.items(), key=lambda x: x[0])
-        p2 = [str(p) for p in p1]
-        p3 = '|'.join(p2)
-        return str(uuid.uuid3(uuid.NAMESPACE_OID, p3))
+        UniUtil.uuidd(param)
 
     @staticmethod
     def time_cost(fn):
@@ -38,13 +66,13 @@ class UniUtil:
 
         def _timer(*args, **kwargs):
             func_name = fn.__name__
-            LogUtil.info('start', func_name)
+            print('start', func_name)
             start = time.perf_counter()
             result = fn(*args, **kwargs)
             end = time.perf_counter()
             cost = _fmt(end - start)
-            LogUtil.info('end', func_name)
-            LogUtil.info('cost', cost)
+            print('end', func_name)
+            print('cost', cost)
             return result
 
         def _fmt(sec):
@@ -110,23 +138,28 @@ class UniUtil:
 class ConfUtil:
     """配置文件【config.ini】操作工具类"""
     CONN = None
+    CFID = None
 
     @classmethod
     def _init(cls, conf):
         if cls.CONN is None:
             cls.connect(conf)
+        elif cls.CFID != UniUtil.get_uuid(conf):
+            cls.connect(conf)
 
     @classmethod
     def connect(cls, conf):
         try:
             cls.CONN = configparser.ConfigParser()
             cls.CONN.read(conf, encoding='utf-8')
+            cls.CFID = UniUtil.get_uuid(conf)
         except Exception as e:
-            LogUtil.error("conf init failed, please check the config", e)
+            print("conf init failed, please check the config", e)
 
     @classmethod
     def get_items(cls, conf, section):
         """获取某一章节的所有信息"""
+        cls._init(conf)
         res = {}
         for item in cls.CONN.items(section):
             res[item[0]] = item[1]
@@ -135,6 +168,7 @@ class ConfUtil:
     @classmethod
     def get_value(cls, conf, section, key):
         """根据章节id获取图片最终序号"""
+        cls._init(conf)
         res = None
         if str(key) in cls.CONN.options(section):
             res = cls.CONN.get(section, str(key))
@@ -143,6 +177,7 @@ class ConfUtil:
     @classmethod
     def set_value(cls, conf, section, key, value):
         """根据章节id设置图片最终序号"""
+        cls._init(conf)
         cls.CONN.set(section, str(key), str(value))
         cls.CONN.write(open(conf, "w", encoding='utf-8'))
 
@@ -150,6 +185,22 @@ class ConfUtil:
 class FileUtil:
     """目录、文件操作工具类"""
 
+    @staticmethod
+    def list_dir(filepath, contains: str = None):
+        """列出目录下的所有文件
+        :contains 包含的字符
+        """
+        res = []
+        for file in os.listdir(filepath):
+            fp = f'{filepath}/{file}'
+            if contains:
+                if contains in file:
+                    res.append(fp)
+            else:
+                res.append(fp)
+        res.sort()
+        return res
+
     @staticmethod
     def create_dir_if_not_exist(dst_dir: str):
         """创建目录，不存在则创建，存在无操作
@@ -218,7 +269,7 @@ class DtUtil:
     DF_CHN_DAY = '%Y年%m月%d日'
     DF_CHN_MON = '%Y年%m月'
     DF_CUS_MIN = '%Y_%m%d_%H%M'
-    DF_INFLUX = '%Y-%m-%dT%H:%M:%SZ'
+    DF_INFLUX = '%Y-%m-%dT%H:%M:%S.%fZ'
 
     # 日期单位
     DU_SEC = 'sec'
@@ -257,11 +308,13 @@ class DtUtil:
             src_dt += relativedelta(hours=-8)
         res = dt.datetime.strftime(src_dt, dst_df)
         if dst_df == DtUtil.DF_INFLUX:
-            mt = str(src_dt.timestamp()).split('.')
-            m1 = mt[0]
-            m2 = mt[1][:3]
-            m3 = 'Z' if m2 == '0' else f'.{m2}Z'
-            res = res.replace('Z', m3)
+            m1 = res.split('.')[0]
+            m2 = str(src_dt.timestamp()).split('.')[1][:3]
+            m22 = eval(m2)
+            m3 = 'Z' if m22 == 0 else f'.{m2}Z'
+            res = f'{m1}{m3}'
+        elif dst_df == DtUtil.DF_STD_MIC:
+            res = res[:-3]
         return res
 
     @staticmethod
@@ -270,9 +323,13 @@ class DtUtil:
         @param src_dt_str:源日期字符串
         @param src_df:源日期字符串格式
         """
-        res = dt.datetime.strptime(src_dt_str, src_df)
         if src_df == DtUtil.DF_INFLUX:
+            if '.' not in src_dt_str:
+                src_dt_str = src_dt_str.replace('Z', '.0Z')
+            res = dt.datetime.strptime(src_dt_str, src_df)
             res += relativedelta(hours=8)
+        else:
+            res = dt.datetime.strptime(src_dt_str, src_df)
         return res
 
     @staticmethod
@@ -284,6 +341,20 @@ class DtUtil:
         """
         return src_dt + relativedelta(months=mon) + relativedelta(days=day) + relativedelta(seconds=sec)
 
+    @staticmethod
+    def shift_date_str(src_dt_str: str, src_df: str = DF_STD_SEC, dst_df: str = None, mon: int = 0, day: int = 0, sec: int = 0):
+        """获取今天日期，根据传入的偏移量偏移，最终返回日期字符串
+        @param src_dt_str:源日期字符串
+        @param src_df:源日期字符串格式
+        @param dst_df:返回日期字符串格式，默认为None代表格式和源格式一样
+        @param mon:日期按月偏移量
+        @param day:日期按日偏移量
+        @param day:日期按秒偏移量
+        """
+        if dst_df is None:
+            dst_df = src_df
+        return DtUtil.convert_date_to_str(DtUtil.shift_date(DtUtil.convert_str_to_date(src_dt_str, src_df), mon=mon, day=day, sec=sec), dst_df)
+
     @staticmethod
     def diff_time(src_dt_str1: str, src_dt_str2: str, src_df: str = DF_STD_SEC, diff_unit=DU_SEC):
         """获取两个日期字符串的时间差，默认单位秒
@@ -501,13 +572,13 @@ class InfluxUtil:
             cls.CONN = InfluxDBClient(**conf)
             cls.CFID = UniUtil.get_uuid(conf)
         except Exception as e:
-            LogUtil.error("influxdb init failed, please check the config", e)
+            print("influxdb init failed, please check the config", e)
 
     @classmethod
     def exec_sql(cls, conf: dict, sql: str):
         """执行influxdb查询sql"""
         cls._init(conf)
-        return list(cls.CONN.query(sql, epoch='ms', chunked=true).get_points())
+        return list(cls.CONN.query(sql, epoch='ms').get_points())
 
     @classmethod
     def write_data(cls, conf: dict, tbl: str, data_list: list):
@@ -584,7 +655,7 @@ class MysqlUtil:
             cls.CONN = pymysql.connect(**conf)
             cls.CFID = UniUtil.get_uuid(conf)
         except Exception as e:
-            LogUtil.error("mysql init failed, please check the config", e)
+            print("mysql init failed, please check the config", e)
 
     @classmethod
     def get(cls, conf: dict, sql: str):
@@ -634,7 +705,7 @@ class ShellUtil:
             cls.CONN.connect(**conf)
             cls.CFID = UniUtil.get_uuid(conf)
         except Exception as e:
-            LogUtil.error("shell init failed, please check the config", e)
+            print("shell init failed, please check the config", e)
 
     @classmethod
     def exec(cls, conf: dict, cmd: str):
@@ -677,7 +748,7 @@ class MinioUtil:
             cls.CONN = minio.Minio(**conf)
             cls.CFID = UniUtil.get_uuid(conf)
         except Exception as e:
-            LogUtil.error("minio init failed, please check the config", e)
+            print("minio init failed, please check the config", e)
 
     @classmethod
     def upload(cls, conf: dict, bucket: str, filepath: str, filename: str):
@@ -756,7 +827,7 @@ class RedisUtil:
             cls.CONN = redis.Redis(connection_pool=pool)
             cls.CFID = UniUtil.get_uuid(conf)
         except Exception as e:
-            LogUtil.error("redis init failed, please check the config", e)
+            print("redis init failed, please check the config", e)
 
     @classmethod
     def exist(cls, key: str):
